@@ -139,11 +139,12 @@ class ShynaIs:
                 self.is_this = False
             else:
                 for face_time in self.result:
-                    time_diff = self.s_time.string_to_time_with_date(self.s_time.now_time) - self.s_time.string_to_time_with_date(face_time[0])
-                    face_time_list.append(str(time_diff))
+                    time_diff = (self.s_time.string_to_time_with_date(self.s_time.now_time) - self.s_time.string_to_time_with_date(face_time[0])).total_seconds()
+                    face_time_list.append(time_diff)
                 face_time_list = sorted(face_time_list)
                 for item in face_time_list:
-                    if self.s_time.string_to_time_with_date(item) < self.s_time.string_to_time_with_date("00:10:00"):
+                    print(item)
+                    if int(item) < 60:
                         response.append(True)
                     else:
                         response.append(False)
@@ -542,20 +543,23 @@ class ShynaIs:
     def saw_after_long_time(self):
         self.is_this = False
         try:
-            self.s_data.query = "Select task_time from shivam_face where task_date='" + str(self.s_time.now_date) + "' order by count DESC limit 2"
+            self.s_data.query = "Select task_time from shivam_face where task_date='" + str(self.s_time.now_date) + "' order by count DESC limit 4"
             self.result = self.s_data.select_from_table()
             if str(self.result[0]).lower().__contains__('empty'):
                 self.is_this = False
             else:
-                # print(self.result[1][0], self.result[0][0])
-                time_diff = (self.s_time.string_to_time_with_date(time_string=str(self.result[1][0])) - self.s_time.string_to_time_with_date(time_string=str(self.result[0][0]))).total_seconds()
-                # print(time_diff)
-                if int(time_diff) >= 300:
-                    self.is_this = True
-                else:
-                    self.is_this = False
+                for i in range(len(self.result)):
+                    print(self.result[i][0])
+                    time_diff = (self.s_time.string_to_time_with_date(time_string=str(self.result[i][0])) - self.s_time.string_to_time_with_date(time_string=str(self.result[i+1][0]))).total_seconds()
+                    print(time_diff)
+                    if 60 < int(time_diff) < 100:
+                        self.is_this = True
+                        break
+                    else:
+                        self.is_this = False
         except Exception as e:
             self.is_this = False
             print(e)
         finally:
             return self.is_this
+
